@@ -17,6 +17,16 @@ CACHE_ACCURACY = 5
 logger = getLogger(__name__)
 
 def latlng_valid(latitude, longitude):
+    try:
+        latitude = float(latitude)
+    except ValueError:
+        logger.error(f"Invalid latitude: {latitude}")
+        return None
+    try:
+        longitude = float(longitude)
+    except ValueError:
+        logger.error(f"Invalid longitude: {longitude}")
+        return None
     if (not isinstance(latitude, float)) or (not isinstance(longitude, float)):
         logger.error(f"Invalid latitude, longitude ({latitude}, {longitude})")
         return None
@@ -135,16 +145,4 @@ class GCPGeocoding():
         return r.country, r.locality, r.neighborhood
 
 if __name__ == '__main__':
-    geocoding = GCPGeocoding(api_key='AIzaSyAIy2BqQXz0Ua4VuUUKMtUbiJxwijU06zQ')
-
-    home = (22.231540, 114.228420)
-    nwd = (22.290802, 114.1500854)
-    addr1 = (23.11810303, 113.2539063)
-
-    # results = geocoding.reverse(home[0], home[1])
-    print(geocoding.reverse_brief(addr1[0], addr1[1]))
-    # results = geocoding.reverse(nwd[0], nwd[1])
-    # print(json.dumps(results.processed_results, indent=4))
-    # print(json.dumps(results.results, indent=4))
-
-    # print(json.dumps(results.results, indent=4))
\ No newline at end of file
+    pass
